@@ -11,6 +11,7 @@ from pythonjsonlogger import jsonlogger
 
 logger = logging.getLogger()
 
+logger.setLevel(level=logging.DEBUG)
 logHandler = logging.StreamHandler()
 formatter = jsonlogger.JsonFormatter()
 logHandler.setFormatter(formatter)
@@ -131,12 +132,16 @@ def upload_loop():
             try:
                 start = datetime.datetime.now()
                 mp4_name = f"{name[:-5]}.mp4"
-                (
-                    ffmpeg
-                    .input(name, format="h264", r=str(CAMERA_FRAMERATE))
-                    .output(mp4_name, **{"format": "mp4", "c:v": "copy", "r": str(CAMERA_FRAMERATE)})
-                    .run(quiet=False, overwrite_output=True)
-                )
+                try:
+                    (
+                        ffmpeg
+                        .input(name, format="h264", r=str(CAMERA_FRAMERATE))
+                        .output(mp4_name, **{"format": "mp4", "c:v": "copy", "r": str(CAMERA_FRAMERATE)})
+                        .run(quiet=True, overwrite_output=True)
+                    )
+                except Exception as ffmpeg_err:
+                    logger.exception(ffmpeg_err)
+                    logger.exception("ffmpeg_err %s", name)
                 logger.info('repackage took %s', (datetime.datetime.now() - start).total_seconds())
                 time.sleep(1)
                 ts = name[11:-5]
@@ -150,7 +155,7 @@ def upload_loop():
                 os.remove(name)
                 os.remove(mp4_name)
             except MinioException as err:
-                logger.info(err)
-                logger.info("failed to process %s", name)
+                logger.exception(err)
+                logger.exception("failed to process %s", name)
         else:
             time.sleep(2)
